Summary: The GNU libc libraries.
Name: glibc
Version: 2.1.3
Release: 29
Copyright: LGPL
Group: System Environment/Libraries
Source: %{name}-%{version}.tar.gz
# Other sources are available at:
#   http://www.ozemail.com.au/~geoffk/glibc-crypt/glibc-crypt-2.1.tar.gz
# In the source tarball the file diff-CYGNUS-to-REDHAT.patch contains all
# diffs applied by Red Hat to the current CVS version of glibc
Patch1: glibc-2.1.3-security.patch
Patch2: glibc-2.1.3-locale.patch
Patch3: glibc-2.1.3-crypt.patch
Patch4: glibc-2.1.3-tzfile.patch
Patch5: glibc-2.1.3-pthread.patch
Patch6: glibc-2.1.3-preload.patch
Patch7: glibc-2.1.3-alpha.patch
Patch8: glibc-2.1.3-glob.patch
Patch9: glibc-2.1.3-security2.patch
Patch10: glibc-2.1.3-xdr_array.patch
Patch11: glibc-2.1.3-calloc.patch
Patch12: glibc-2.1.3-maxpacket.patch
Patch13: glibc-2.1.3-xdrmem.patch
Buildroot: /var/tmp/glibc-%{PACKAGE_VERSION}-root
Obsoletes: zoneinfo, libc-static, libc-devel, libc-profile, libc-headers,
Obsoletes:  linuxthreads, gencat, locale
Autoreq: false
%ifarch alpha
Provides: ld.so.2
%else
%endif
%ifarch sparc
Obsoletes: libc
%endif

%description
The glibc package contains standard libraries which are used by
multiple programs on the system. In order to save disk space and
memory, as well as to make upgrading easier, common system code is
kept in one place and shared between programs. This particular package
contains the most important sets of shared libraries: the standard C
library and the standard math library. Without these two libraries, a
Linux system will not function.  The glibc package also contains
national language (locale) support and timezone databases.

%package devel
Summary: Header and object files for development using standard C libraries.
Group: Development/Libraries
Conflicts: texinfo < 3.11
Prereq: /sbin/install-info
Obsoletes: libc-debug, libc-headers, libc-devel, linuxthreads-devel
Obsoletes: glibc-debug
Prereq: kernel-headers
Requires: kernel-headers >= 2.2.1
Autoreq: true

%description devel
The glibc-devel package contains the header and object files necessary
for developing programs which use the standard C libraries (which are
used by nearly all programs).  If you are developing programs which
will use the standard C libraries, your system needs to have these
standard header and object files available in order to create the
executables.

Install glibc-devel if you are going to develop programs which will
use the standard C libraries.

%package profile
Summary: The GNU libc libraries, including support for gprof profiling.
Group: Development/Libraries
Obsoletes: libc-profile
Autoreq: true

%description profile
The glibc-profile package includes the GNU libc libraries and support
for profiling using the gprof program.  Profiling is analyzing a
program's functions to see how much CPU time they use and determining
which functions are calling other functions during execution.  To use
gprof to profile a program, your program needs to use the GNU libc
libraries included in glibc-profile (instead of the standard GNU libc
libraries included in the glibc package).

If you are going to use the gprof program to profile a program, you'll
need to install the glibc-profile program.

%package -n nscd
Summary: A Name Service Caching Daemon (nscd).
Group: System Environment/Daemons
Conflicts: kernel < 2.2.0
Prereq: /sbin/chkconfig
Autoreq: true

%description -n nscd
Nscd caches name service lookups and can dramatically improve
performance with NIS+, and may help with DNS as well. Note that you
can't use nscd with 2.0 kernels because of bugs in the kernel-side
thread support. Unfortunately, nscd happens to hit these bugs
particularly hard.

Install nscd if you need a name service lookup caching daemon, and
you're not using a version 2.0 kernel.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1

perl -pi -e 'm/PACKET.*1024/ and s/1024/65536/' \
  `find resolv glibc-compat -name \*.c`
 
%ifarch armv4l
rm -rf glibc-compat
%endif

find . -type f -size 0 -o -name "*.orig" -exec rm -f {} \;

%build
rm -rf build-$RPM_ARCH-linux
mkdir build-$RPM_ARCH-linux ; cd build-$RPM_ARCH-linux
%ifarch i586 i686
BuildFlags="-mpentium -D__USE_STRING_INLINES -fstrict-aliasing -mcpu=%{_target_cpu}"
%endif
%ifarch sparcv9
BuildFlags="-mv8 -mtune=ultrasparc"
%endif
CC=egcs CFLAGS="$BuildFlags -g -O3" ../configure --prefix=/usr \
	--enable-add-ons=yes --without-cvs  \
	%{_target_cpu}-redhat-linux
make -r CFLAGS="$BuildFlags -g -O3" PARALLELMFLAGS=-s

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
make install_root=$RPM_BUILD_ROOT install -C build-$RPM_ARCH-linux
cd build-$RPM_ARCH-linux && \
    make install_root=$RPM_BUILD_ROOT install-locales -C ../localedata objdir=`pwd` && \
    cd ..

# compatibility hack: this locale has vanished from glibc, but some other
# programs are still using it. Normally we would handle it in the %pre
# section but with glibc that is simply not an option
mkdir -p $RPM_BUILD_ROOT/usr/share/locale/ru_RU/LC_MESSAGES

# Remove the files we don't want to distribute
rm -f $RPM_BUILD_ROOT/usr/lib/libNoVersion*

# the man pages for the linuxthreads require special attention
make -C linuxthreads/man
mkdir -p $RPM_BUILD_ROOT/usr/man/man3
install -m 0644 linuxthreads/man/*.3thr $RPM_BUILD_ROOT/usr/man/man3
gzip -9nvf $RPM_BUILD_ROOT/usr/man/man3/*

gzip -9nvf $RPM_BUILD_ROOT/usr/info/libc*

ln -sf libbsd-compat.a $RPM_BUILD_ROOT/usr/lib/libbsd.a

install -m 644 redhat/nsswitch.conf $RPM_BUILD_ROOT/etc/nsswitch.conf

# Take care of setuids
# -- new security review sez that this shouldn't be needed anymore
#chmod 755 $RPM_BUILD_ROOT/usr/libexec/pt_chown

# This is for ncsd - in glibc 2.1
install -m 644 nscd/nscd.conf $RPM_BUILD_ROOT/etc
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 755 nscd/nscd.init $RPM_BUILD_ROOT/etc/rc.d/init.d/nscd

# The database support
mkdir -p $RPM_BUILD_ROOT/var/db
install -m 644 nss/db-Makefile $RPM_BUILD_ROOT/var/db/Makefile

# Strip binaries
strip $RPM_BUILD_ROOT/sbin/* || :
strip $RPM_BUILD_ROOT/usr/bin/* || :
strip $RPM_BUILD_ROOT/usr/sbin/* || :

# BUILD THE FILE LIST
find $RPM_BUILD_ROOT -type f -or -type l | 
	sed -e 's|.*/etc|%config &|' > rpm.filelist.in
for n in /usr/share /usr/include; do 
    find ${RPM_BUILD_ROOT}${n} -type d | \
	grep -v '^/usr/share$' | \
	sed "s/^/%dir /" >> rpm.filelist.in
done

# primary filelist
sed "s|$RPM_BUILD_ROOT||" < rpm.filelist.in | 
	grep -v '/etc/localtime'  | \
	grep -v '/etc/nsswitch.conf'  | \
	sort > rpm.filelist

grep '/usr/lib/lib.*_p\.a' < rpm.filelist > profile.filelist
egrep "(/usr/include)|(/usr/info)" < rpm.filelist | 
	grep -v /usr/info/dir > devel.filelist

mv rpm.filelist rpm.filelist.full
grep -v '/usr/lib/lib.*_p.a' rpm.filelist.full | 
	egrep -v "(/usr/include)|(/usr/info)" > rpm.filelist

grep '/usr/lib/lib.*\.a' < rpm.filelist >> devel.filelist
grep '/usr/lib/.*\.o' < rpm.filelist >> devel.filelist
grep '/usr/lib/lib.*\.so' < rpm.filelist >> devel.filelist
grep '/usr/man/man' < rpm.filelist >> devel.filelist

mv rpm.filelist rpm.filelist.full
grep -v '/usr/lib/lib.*\.a' < rpm.filelist.full |
	grep -v '/usr/lib/.*\.o' |
	grep -v '/usr/lib/lib.*\.so'|
	grep -v '/usr/man/man' | 
	grep -v 'nscd' > rpm.filelist

# /etc/localtime - we're proud of our timezone
rm -f $RPM_BUILD_ROOT/etc/localtime
cp -f $RPM_BUILD_ROOT/usr/share/zoneinfo/US/Eastern $RPM_BUILD_ROOT/etc/localtime
#ln -sf ../usr/share/zoneinfo/US/Eastern $RPM_BUILD_ROOT/etc/localtime

# the last bit: more documentation
rm -rf documentation
mkdir documentation
cp linuxthreads/ChangeLog  documentation/ChangeLog.threads
cp linuxthreads/Changes documentation/Changes.threads
cp linuxthreads/README documentation/README.threads
cp linuxthreads/FAQ.html documentation/FAQ-threads.html
cp -r linuxthreads/Examples documentation/examples.threads
cp crypt/README documentation/README.crypt
cp db2/README documentation/README.db2
cp db2/mutex/README documentation/README.db2.mutex
cp timezone/README documentation/README.timezone
cp ChangeLog* documentation
gzip -9 documentation/ChangeLog*

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info /usr/info/libc.info.gz /usr/info/dir

%pre devel
# this used to be a link and it is causing nightmares now
if [ -L /usr/include/scsi ] ; then
    rm -f /usr/include/scsi
fi

%preun devel
if [ "$1" = 0 ]; then
    /sbin/install-info --delete /usr/info/libc.info.gz /usr/info/dir
fi

%post -n nscd
/sbin/chkconfig --add nscd

%preun -n nscd
if [ $1 = 0 ] ; then
    /sbin/chkconfig --del nscd
fi

%clean
rm -rf "$RPM_BUILD_ROOT"
rm -f *.filelist*

%files -f rpm.filelist
%defattr(-,root,root)
%config(noreplace) /etc/localtime
%config(noreplace) /etc/nsswitch.conf
%doc README NEWS INSTALL FAQ BUGS NOTES PROJECTS
%doc documentation/* README.template README.libm
%doc login/README.utmpd hesiod/README.hesiod
%dir /var/db

%ifnarch sparcv9 i586 i686
%files -f devel.filelist devel
%defattr(-,root,root)

%files -f profile.filelist profile
%defattr(-,root,root)

%files -n nscd
%defattr(-,root,root)
%config /etc/nscd.conf
/etc/rc.d/init.d/nscd
/usr/sbin/nscd
%endif

%define date    %(echo `LC_ALL="C" date +"%a %b %d %Y"`)

%changelog
* Wed Mar  5 2003 Jakub Jelinek <jakub@redhat.com> 2.1.3-29
- fix overflows in xdrmem (Paul Eggert, Roland McGrath)

* Thu Oct 12 2002 Jakub Jelinek <jakub@redhat.com> 2.1.3-28
- use malloc instead of alloca for get*by* functions, so that
  they work even with extremely low stack sizes (#75128, #75616)

* Mon Sep  9 2002 Jakub Jelinek <jakub@redhat.com> 2.1.3-27
- fix resolver buffer overflows

* Wed Aug  7 2002 Jakub Jelinek <jakub@redhat.com> 2.1.3-26
- fix the calloc patch so that calloc (131072, 0) doesn't
  crash

* Thu Aug  1 2002 Jakub Jelinek <jakub@redhat.com> 2.1.3-25
- fix xdr_array buffer overflow
- fix calloc overflow (both patches by Solar Designer)

* Tue Jul  9 2002 Jakub Jelinek <jakub@redhat.com> 2.1.3-24
- fix buffer overflows in getnetby* (if nsswitch.conf
  network: line includes dns) and gethostby* for apps compiled
  against glibc 2.0.

* Sat Dec  8 2001 Jakub Jelinek <jakub@redhat.com>
- fix glob buffer overflow

* Mon Jan 15 2001 Jakub Jelinek <jakub@redhat.com>
- fix LD_PRELOAD security bug
- fix LD_PROFILE file handling in SUID/SGID binaries
- add alpha related patches from glibc-2.1.3-16 (#20832)

* Tue Sep  5 2000 Jakub Jelinek <jakub@redhat.com>
- reinstall the thread deadlock fix, it is innocent.
  Use the Feb, 29th tarball of glibc, not Mar, 27th, as that
  change breaks JDK.

* Tue Sep  5 2000 Jakub Jelinek <jakub@redhat.com>
- back out the thread deadlock fix, it breaks some JDKs.

* Fri Sep  1 2000 Jakub Jelinek <jakub@redhat.com>
- two more locale related security fixes

* Thu Aug 31 2000 Jakub Jelinek <jakub@redhat.com>
- don't allow LANG/LC_* to contain / in suid/sgid programs
- Solar Designer's crypt alignment patch

* Fri Aug 25 2000 Jakub Jelinek <jakub@redhat.com>
- properly unset LD_ variables in setuid/setgid applications
- fix timezone handling with certain settings of TZ environment variable
- avoid thread deadlocks in certain situations (#13785)

* Fri Feb 25 2000 Cristian Gafton <gafton@redhat.com>
- fix c_stubs add-on to work around various assert()s in glibc
- add Davem's patch for _NPROCESSORS_ONLN on Sparc

* Fri Feb 25 2000 Cristian Gafton <gafton@redhat.com>
- add the c_stubs add-on
- sparc patch from davem

* Thu Feb 24 2000 Cristian Gafton <gafton@redhat.com>
- fix locale problems on 64 bit arches

* Tue Feb 22 2000 Cristian Gafton <gafton@redhat.com>
- cygnus sync up for fixes to nscd

* Thu Feb 17 2000 Cristian Gafton <gafton@redhat.com>
- updated to include new China timezones
- sync up with the locale changes from Cygnus

* Tue Feb 01 2000 Cristian Gafton <gafton@redhat.com>
- updated from cygnus branch
- fix syslog so that it will continuously try to fallback from SOK_DGRAM to
  SOCK_STREAM and backwards

* Mon Jan 31 2000 Cristian Gafton <gafton@redhat.com>
- update from cygnus branch
- compress man pages for the linuxthreads stuff

* Fri Jan 21 2000 Cristian Gafton <gafton@redhat.com>
- add Jakub's patch so we back out even more

* Thu Jan 20 2000 Cristian Gafton <gafton@redhat.com>
- back out the setrlimit changes (well, sort of)

* Mon Jan 03 2000 Cristian Gafton <gafton@redhat.com>
- make release from CVS server directly now
